@@ -25,7 +25,6 @@
 #include <signal.h>
 #include <string.h>
 #include "procdialogs.h"
-#include "favorites.h"
 #include "proctable.h"
 #include "callbacks.h"
 #include "prettytable.h"
@@ -41,59 +40,6 @@ static GtkWidget *prefs_dialog = NULL;
 static gint new_nice_value = 0;
 
 
-static void
-hide_dialog_button_pressed (GtkDialog *dialog, gint id, gpointer data)
-{
-	ProcData *procdata = static_cast<ProcData*>(data);
-	
-	if (id == GTK_RESPONSE_OK) {
-		add_selected_to_blacklist (procdata);
-	}
-	
-	gtk_widget_destroy (GTK_WIDGET (dialog));
-		
-}
-
-void
-procdialog_create_hide_dialog (ProcData *data)
-{
-       ProcData *procdata = static_cast<ProcData*>(data);
-       GtkWidget *hide_alert_dialog;
-       gchar *message;
-
-       /*translators: primary alert message*/
-       message = g_strdup_printf (_("Hide the selected process?"));
-       hide_alert_dialog = gtk_message_dialog_new (GTK_WINDOW (procdata->app),
-						   static_cast<GtkDialogFlags>(GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT),
-						   GTK_MESSAGE_WARNING,
-						   GTK_BUTTONS_NONE,
-						   message);
-       g_free (message);
-
-       /* FIXME: View menu -> Edit menu */
-       /*translators: secondary alert messagex*/
-       message = g_strdup_printf (_("Hidden processes are no longer visible "
-				    "in the process list. You can re-enable "
-				    "them by selecting the \"Hidden Processes\" "
-				    "entry in the View menu."));
-       gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (hide_alert_dialog),
-						 message);
-       g_free (message);
-
-       gtk_dialog_add_buttons (GTK_DIALOG (hide_alert_dialog),
-                               GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-                               _("_Hide Process"), GTK_RESPONSE_OK,
-                               NULL);
-       gtk_dialog_set_default_response (GTK_DIALOG (hide_alert_dialog),
-                                        GTK_RESPONSE_OK);
-	
-       g_signal_connect (G_OBJECT (hide_alert_dialog), "response",
-			 G_CALLBACK (hide_dialog_button_pressed), procdata);
-  	
-       gtk_widget_show_all (hide_alert_dialog);
-
-}
-
 static void
 kill_dialog_button_pressed (GtkDialog *dialog, gint id, gpointer data)
 {
@@ -180,7 +126,7 @@ renice_scale_changed (GtkAdjustment *adj, gpointer data)
 {
 	GtkWidget *label = GTK_WIDGET (data);
 	
-	new_nice_value = adj->value;
+	new_nice_value = int(adj->value);
 	gtk_label_set_text (GTK_LABEL (label), get_nice_level (new_nice_value));		
 	
 }
@@ -335,7 +281,7 @@ smooth_refresh_toggled(GtkToggleButton *button, gpointer data)
 
 	toggled = gtk_toggle_button_get_active(button);
 
-	gconf_client_set_bool(client, SMOOTH_REFRESH_KEY, toggled, NULL);
+	gconf_client_set_bool(client, SmoothRefresh::KEY.c_str(), toggled, NULL);
 }
 
 
@@ -354,73 +300,42 @@ show_all_fs_toggled (GtkToggleButton *button, gpointer data)
 }
 
 
-static void
-show_hide_dialog_toggled (GtkToggleButton *button, gpointer data)
+class SpinButtonUpdater
 {
-	ProcData *procdata = static_cast<ProcData*>(data);
-	GConfClient *client = procdata->client;
-	
-	gboolean toggled;
-	
-	toggled = gtk_toggle_button_get_active (button);
-	
-	gconf_client_set_bool (client, "/apps/procman/hide_message", toggled, NULL);
-		
-}
+public:
+  SpinButtonUpdater(const string& gconf_key)
+    : gconf_key(gconf_key)
+  { }
 
-static gboolean
-update_update_interval (GtkWidget *widget, GdkEventFocus *event, gpointer data)
-{
-	ProcData *procdata = static_cast<ProcData*>(data);
-	GConfClient *client = procdata->client;
-	GtkWidget *spin_button;
-	guint value;
-	
-	spin_button = widget;
-	value = gtk_spin_button_get_value (GTK_SPIN_BUTTON (spin_button));
-	
-	if (1000 * value == procdata->config.update_interval)
-		return FALSE;
-		
-	gconf_client_set_int (client, "/apps/procman/update_interval", value * 1000, NULL);
-	return FALSE;
-}
+  static gboolean callback(GtkWidget *widget, GdkEventFocus *event, gpointer data)
+  {
+    SpinButtonUpdater* updater = static_cast<SpinButtonUpdater*>(data);
+    updater->update(GTK_SPIN_BUTTON(widget));
+    return FALSE;
+  }
 
-static gboolean
-update_graph_update_interval (GtkWidget *widget, GdkEventFocus *event, gpointer data)
-{
-	ProcData *procdata = static_cast<ProcData*>(data);
-	GConfClient *client = procdata->client;
-	GtkWidget *spin_button;
-	guint value = 0;
+private:
 
-	spin_button = widget;
-	value = gtk_spin_button_get_value (GTK_SPIN_BUTTON (spin_button));
-	
-	if (1000 * value == procdata->config.graph_update_interval)
-		return FALSE;
+  void update(GtkSpinButton* spin)
+  {
+    int new_value = int(1000 * gtk_spin_button_get_value(spin));
+    GError* e = 0;
 
-	gconf_client_set_int (client, "/apps/procman/graph_update_interval", value * 1000, NULL);
-	return FALSE;
-}
+    if (not gconf_client_set_int(ProcData::get_instance()->client,
+				 this->gconf_key.c_str(), new_value,
+				 &e)) {
+      g_warning("Failed to gconf_client_set_int %s %d : %s\n",
+		this->gconf_key.c_str(), new_value, e->message);
+      g_error_free(e);
+    }
+
+    procman_debug("set %s to %d", this->gconf_key.c_str(), new_value);
+  }
+
+  const string gconf_key;
+};
 
-static gboolean
-update_disks_update_interval (GtkWidget *widget, GdkEventFocus *event, gpointer data)
-{
-	ProcData *procdata = static_cast<ProcData*>(data);
-	GConfClient *client = procdata->client;
-	GtkWidget *spin_button;
-	guint value;
 
-	spin_button = widget;
-	value = gtk_spin_button_get_value (GTK_SPIN_BUTTON (spin_button));
-	
-	if (1000 * value == procdata->config.disks_update_interval)
-		return FALSE;
-		
-	gconf_client_set_int (client, "/apps/procman/disks_interval", value * 1000, NULL);
-	return FALSE;
-}
 
 
 static void
@@ -530,6 +445,13 @@ void
 procdialog_create_preferences_dialog (ProcData *procdata)
 {
 	static GtkWidget *dialog = NULL;
+
+	typedef SpinButtonUpdater SBU;
+
+	static SBU interval_updater("/apps/procman/update_interval");
+	static SBU graph_interval_updater("/apps/procman/graph_update_interval");
+	static SBU disks_interval_updater("/apps/procman/disks_interval");
+
 	GtkWidget *notebook;
 	GtkWidget *proc_box;
 	GtkWidget *sys_box;
@@ -620,7 +542,7 @@ procdialog_create_preferences_dialog (ProcData *procdata)
 	spin_button = gtk_spin_button_new (adjustment, 1.0, 2);
 	gtk_box_pack_start (GTK_BOX (hbox3), spin_button, FALSE, FALSE, 0);
 	g_signal_connect (G_OBJECT (spin_button), "focus_out_event",
-				   G_CALLBACK (update_update_interval), procdata);
+				   G_CALLBACK (SBU::callback), &interval_updater);
 	gtk_label_set_mnemonic_widget (GTK_LABEL (label), spin_button);
 	
 
@@ -630,7 +552,7 @@ procdialog_create_preferences_dialog (ProcData *procdata)
 	smooth_button = gtk_check_button_new_with_mnemonic(_("Enable _smooth refresh"));
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(smooth_button),
 				     gconf_client_get_bool(procdata->client,
-							   SMOOTH_REFRESH_KEY,
+							   SmoothRefresh::KEY.c_str(),
 							   NULL));
 	g_signal_connect(G_OBJECT(smooth_button), "toggled",
 			 G_CALLBACK(smooth_refresh_toggled), procdata);
@@ -651,13 +573,6 @@ procdialog_create_preferences_dialog (ProcData *procdata)
 	hbox2 = gtk_hbox_new (FALSE, 6);
 	gtk_box_pack_start (GTK_BOX (vbox2), hbox2, FALSE, FALSE, 0);
 	
-	check_button = gtk_check_button_new_with_mnemonic (_("Alert before _hiding processes"));
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check_button), 
-				    procdata->config.show_hide_message);
-	g_signal_connect (G_OBJECT (check_button), "toggled",
-			    G_CALLBACK (show_hide_dialog_toggled), procdata);
-	gtk_box_pack_start (GTK_BOX (hbox2), check_button, FALSE, FALSE, 0);
-	
 	vbox = gtk_vbox_new (FALSE, 6);
 	gtk_box_pack_start (GTK_BOX (proc_box), vbox, TRUE, TRUE, 0);
 	
@@ -718,7 +633,8 @@ procdialog_create_preferences_dialog (ProcData *procdata)
 							  100.0, 0.25, 1.0, 1.0);
 	spin_button = gtk_spin_button_new (adjustment, 1.0, 2);
 	g_signal_connect (G_OBJECT (spin_button), "focus_out_event",
-				   G_CALLBACK (update_graph_update_interval), procdata);
+			  G_CALLBACK(SBU::callback),
+			  &graph_interval_updater);
 	gtk_box_pack_start (GTK_BOX (hbox3), spin_button, FALSE, FALSE, 0);
 	gtk_label_set_mnemonic_widget (GTK_LABEL (label), spin_button);
 	
@@ -804,7 +720,8 @@ procdialog_create_preferences_dialog (ProcData *procdata)
 	gtk_box_pack_start (GTK_BOX (hbox3), spin_button, FALSE, FALSE, 0);
 	gtk_label_set_mnemonic_widget (GTK_LABEL (label), spin_button);
 	g_signal_connect (G_OBJECT (spin_button), "focus_out_event",
-				  G_CALLBACK (update_disks_update_interval), procdata);
+			  G_CALLBACK(SBU::callback),
+			  &disks_interval_updater);
 		
 
 	hbox2 = gtk_hbox_new (FALSE, 6);
